@@ -1981,8 +1981,6 @@ launcher_plugin_button_press_event (GtkWidget      *button,
                                       launcher_plugin_menu_popup_destroyed);
     }
 
-  gtk_widget_set_state_flags (button, GTK_STATE_FLAG_CHECKED, FALSE);
-
   return FALSE;
 }
 
@@ -2019,8 +2017,6 @@ launcher_plugin_button_release_event (GtkWidget      *button,
   else
     return TRUE;
 
-  gtk_widget_set_state_flags (button, GTK_STATE_FLAG_NORMAL, TRUE);
-
   return FALSE;
 }
 
@@ -2502,11 +2498,11 @@ launcher_plugin_item_exec_on_screen (GarconMenuItem *item,
   if (g_shell_parse_argv (command, NULL, &argv, &error))
     {
       /* launch the command on the screen */
-      succeed = xfce_spawn_on_screen (screen,
-                                      garcon_menu_item_get_path (item),
-                                      argv, NULL, G_SPAWN_SEARCH_PATH,
-                                      garcon_menu_item_supports_startup_notification (item),
-                                      event_time, icon, &error);
+      succeed = xfce_spawn (screen,
+                            garcon_menu_item_get_path (item),
+                            argv, NULL, G_SPAWN_SEARCH_PATH,
+                            garcon_menu_item_supports_startup_notification (item),
+                            event_time, icon, FALSE, &error);
 
       g_strfreev (argv);
     }
